@@ -37,7 +37,7 @@ QString get_menu_entry_from_path( const QString& path_P );
 
 Q_DECL_EXPORT void init_global_data( bool active_P, QObject* owner_P );
 
-const char* const MENU_EDITOR_ENTRIES_GROUP_NAME = I18N_NOOP( "Menu Editor entries" );
+const char MENU_EDITOR_ENTRIES_GROUP_NAME[] = I18N_NOOP( "Menu Editor entries" );
 
 //***************************************************************************
 // Inline
